@@ -1,16 +1,25 @@
 from typing import List
 
-
-def send(queue, message_body: List[str], group_id = None):
-    msg_num = len(message_body)
-    if group_id:
-        msg_list = [{'Id': '{}'.format(i+1), 'MessageBody': message_body[i], 'MessageGroupId': 'group' + str(group_id)} for i in range(msg_num)]
-    else:
-        msg_list = [{'Id': '{}'.format(i+1), 'MessageBody': message_body[i], 'MessageGroupId': 'group'} for i in range(msg_num)]
+def send(queue, msg_list):
     size = 10
     for start in range(0, len(msg_list), size):
         queue.send_messages(Entries=msg_list[start: start + size])
 
+def send_execute_message(queue, message_body: str, executor_id: int, executor_key: str):
+    message_group_id = f"group_{executor_key}_{str(executor_id)}"
+    msg_list = [{'Id': "0", 'MessageBody': message_body, 'MessageGroupId': message_group_id}]
+    send(queue=queue, msg_list=msg_list)
+
+def send_executor_task_message(queue, message_body_list: List[str], executor_key: str):
+    msg_num = len(message_body_list)
+    message_group_id = f"group_{executor_key}"
+    msg_list = [{'Id': '{}'.format(i+1), 'MessageBody': message_body_list[i], 'MessageGroupId': message_group_id} for i in range(msg_num)]
+    send(queue=queue, msg_list=msg_list)
+
+def send_driver_trigger_message(queue, message_body: str, executor_id: int, executor_key: str):
+    message_group_id = f"group_{executor_key}_{str(executor_id)}"
+    msg_list = [{'Id': "0", 'MessageBody': message_body, 'MessageGroupId': message_group_id}]
+    send(queue=queue, msg_list=msg_list)
 
 def receive(queue, fetch_count=1) -> List[str]:
     msg_list = queue.receive_messages(MaxNumberOfMessages=fetch_count)
@@ -42,17 +51,5 @@ def receive_all(queue) -> List[str]:
             break
     return message_body
 
-def count(queue) -> int:
-    message_body = []
-    while True:
-        # メッセージを取得
-        msg_list = queue.receive_messages(MaxNumberOfMessages=10)
-        if msg_list:
-            for message in msg_list:
-                message_body.append(message.body)
-        else:
-            break
-    return len(message_body)
-
 
 
